<?php

/**
 * This file is part of the Trustpilot library.
 *
 * (c) Antoine Corcy <contact@sbin.dk>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Trustpilot\Tests;

/**
 * @author Antoine Corcy <contact@sbin.dk>
 */
class TestCase extends \PHPUnit_Framework_TestCase
{
    /**
     * The testable feed id.
     *
     * @var integer
     */
    const FEED_ID = 917278;

    /**
     * A testable feed in JSON format.
     * @see: http://s.trustpilot.com/tpelements/917278/f.json.gz
     *
     * @var string
     */
    const FEED = '{"Categories":[{"Name":"Accounting","Position":3,"Count":6,"ImageUrls":{"i100":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/category_badge/en_100_3.png","i120":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/category_badge/en_120_3.png","i140":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/category_badge/en_140_3.png","i180":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/category_badge/en_180_3.png","i220":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/category_badge/en_220_3.png","i280":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/category_badge/en_280_3.png"}},{"Name":"Bags and Luggage","Position":7,"Count":2,"ImageUrls":{"i100":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/category_badge/en_100_10.png","i120":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/category_badge/en_120_10.png","i140":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/category_badge/en_140_10.png","i180":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/category_badge/en_180_10.png","i220":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/category_badge/en_220_10.png","i280":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/category_badge/en_280_10.png"}}],"DomainName":"demoshop.com","FeedUpdateTime":{"UnixTime":1365089831,"Human":"04 April 2013 14:37:11 GMT","HumanDate":"4. Apr"},"ReviewCount":{"Total":105,"DistributionOverStars":[3,1,11,28,62]},"ReviewPageUrl":"http://www.trustpilot.co.uk/review/demoshop.com","Reviews":[{"Created":{"UnixTime":1362668316,"Human":"07 March 2013 13:58:36 GMT","HumanDate":"7. Mar"},"Title":"Testing testing","Content":"Testing like a boss!!!!","TrustScore":{"Score":100,"Stars":5,"Human":"Excellent","StarsImageUrls":{"large":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/l/5.png","medium":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/m/5.png","small":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/s/5.png"}},"CompanyReply":"","User":{"Name":"Jacob Mortensen","City":"Amager","Locale":"da-DK","ReviewCount":2,"IsVerified":false,"HasImage":true,"ImageUrls":{"i24":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/881929/24x24.png","i35":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/881929/35x35.png","i64":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/881929/64x64.png","i73":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/881929/73x73.png"}},"Url":"http://www.trustpilot.co.uk/review/demoshop.com#3943492","IsVerified":false},{"Created":{"UnixTime":1361372339,"Human":"20 February 2013 13:58:59 GMT","HumanDate":"20. Feb"},"Title":"This is a test","Content":"This is a test This is a test This is a test This is a test This is a test","TrustScore":{"Score":100,"Stars":5,"Human":"Excellent","StarsImageUrls":{"large":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/l/5.png","medium":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/m/5.png","small":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/s/5.png"}},"CompanyReply":"","User":{"Name":"Michael Lajlev","City":"Skovby, Galten","Locale":"da-DK","ReviewCount":56,"IsVerified":false,"HasImage":true,"ImageUrls":{"i24":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/68084/24x24.png","i35":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/68084/35x35.png","i64":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/68084/64x64.png","i73":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/68084/73x73.png"}},"Url":"http://www.trustpilot.co.uk/review/demoshop.com#3811975","IsVerified":false},{"Created":{"UnixTime":1333456757,"Human":"03 April 2012 11:39:17 GMT","HumanDate":"3. Apr"},"Title":"Super","Content":"De mooiste demo-shop ooit :)","TrustScore":{"Score":100,"Stars":5,"Human":"Excellent","StarsImageUrls":{"large":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/l/5.png","medium":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/m/5.png","small":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/s/5.png"}},"CompanyReply":"","User":{"Name":"Jan","City":null,"Locale":"nl-NL","ReviewCount":1,"IsVerified":false,"HasImage":false,"ImageUrls":{"i24":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/0/24x24.png","i35":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/0/35x35.png","i64":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/0/64x64.png","i73":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/0/73x73.png"}},"Url":"http://www.trustpilot.co.uk/review/demoshop.com#1764746","IsVerified":true},{"Created":{"UnixTime":1326111450,"Human":"09 January 2012 11:17:30 GMT","HumanDate":"9. Jan"},"Title":"nice","Content":"excellent and nice","TrustScore":{"Score":100,"Stars":5,"Human":"Excellent","StarsImageUrls":{"large":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/l/5.png","medium":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/m/5.png","small":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/s/5.png"}},"CompanyReply":"","User":{"Name":"bhavin","City":"ahmedabad","Locale":"hi-IN","ReviewCount":1,"IsVerified":false,"HasImage":false,"ImageUrls":{"i24":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/0/24x24.png","i35":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/0/35x35.png","i64":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/0/64x64.png","i73":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/0/73x73.png"}},"Url":"http://www.trustpilot.co.uk/review/demoshop.com#1348422","IsVerified":false},{"Created":{"UnixTime":1325600175,"Human":"03 January 2012 13:16:15 GMT","HumanDate":"3. Jan"},"Title":"Besser geht\u0027s nicht!","Content":"Meine Bestellung war super schnell da und sogar der tolle Aufkleber hat\u0027s in einem Stück zu mir nach Hause geschafft.Der ziert jetzt meine Katze :D","TrustScore":{"Score":100,"Stars":5,"Human":"Excellent","StarsImageUrls":{"large":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/l/5.png","medium":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/m/5.png","small":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/s/5.png"}},"CompanyReply":"Danke für deine Bewertung!","User":{"Name":"S. K.","City":null,"Locale":"de-DE","ReviewCount":1,"IsVerified":false,"HasImage":false,"ImageUrls":{"i24":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/0/24x24.png","i35":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/0/35x35.png","i64":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/0/64x64.png","i73":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/0/73x73.png"}},"Url":"http://www.trustpilot.co.uk/review/demoshop.com#1322580","IsVerified":false},{"Created":{"UnixTime":1323424370,"Human":"09 December 2011 08:52:50 GMT","HumanDate":"9. Dec"},"Title":"awesome blossom","Content":"epic epic and more epic","TrustScore":{"Score":100,"Stars":5,"Human":"Excellent","StarsImageUrls":{"large":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/l/5.png","medium":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/m/5.png","small":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/s/5.png"}},"CompanyReply":"I totally agree with this awesome person","User":{"Name":"Johnny Cummins","City":"Frederiksberg","Locale":"da-DK","ReviewCount":4,"IsVerified":false,"HasImage":true,"ImageUrls":{"i24":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/1032370/24x24.png","i35":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/1032370/35x35.png","i64":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/1032370/64x64.png","i73":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/1032370/73x73.png"}},"Url":"http://www.trustpilot.co.uk/review/demoshop.com#1209210","IsVerified":true},{"Created":{"UnixTime":1320313893,"Human":"03 November 2011 08:51:33 GMT","HumanDate":"3. Nov"},"Title":"SQWDQWD","Content":"DADwefwefwf","TrustScore":{"Score":100,"Stars":5,"Human":"Excellent","StarsImageUrls":{"large":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/l/5.png","medium":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/m/5.png","small":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/s/5.png"}},"CompanyReply":"","User":{"Name":"Erik Nawrowski","City":null,"Locale":"de-DE","ReviewCount":1,"IsVerified":false,"HasImage":false,"ImageUrls":{"i24":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/0/24x24.png","i35":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/0/35x35.png","i64":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/0/64x64.png","i73":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/0/73x73.png"}},"Url":"http://www.trustpilot.co.uk/review/demoshop.com#1073626","IsVerified":true},{"Created":{"UnixTime":1318338840,"Human":"11 October 2011 12:14:00 GMT","HumanDate":"11. Oct"},"Title":"Tres belle solution !","Content":"A découvrir rapidement.","TrustScore":{"Score":100,"Stars":5,"Human":"Excellent","StarsImageUrls":{"large":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/l/5.png","medium":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/m/5.png","small":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/s/5.png"}},"CompanyReply":"","User":{"Name":"ripoche","City":null,"Locale":"fr-FR","ReviewCount":1,"IsVerified":false,"HasImage":false,"ImageUrls":{"i24":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/0/24x24.png","i35":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/0/35x35.png","i64":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/0/64x64.png","i73":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/0/73x73.png"}},"Url":"http://www.trustpilot.co.uk/review/demoshop.com#999702","IsVerified":true},{"Created":{"UnixTime":1287133789,"Human":"15 October 2010 08:09:49 GMT","HumanDate":"15. Oct"},"Title":"Good stuf!","Content":"Good prizes and service. I would have given them 5 stars if their webshop didn\u0027t crash on me all the time.","TrustScore":{"Score":75,"Stars":4,"Human":"Good","StarsImageUrls":{"large":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/l/4.png","medium":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/m/4.png","small":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/s/4.png"}},"CompanyReply":"That\u0027s kind of you, Sir.","User":{"Name":"thomas","City":null,"Locale":"da-DK","ReviewCount":10,"IsVerified":false,"HasImage":true,"ImageUrls":{"i24":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/206863/24x24.png","i35":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/206863/35x35.png","i64":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/206863/64x64.png","i73":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/206863/73x73.png"}},"Url":"http://www.trustpilot.co.uk/review/demoshop.com#366058","IsVerified":false},{"Created":{"UnixTime":1364980209,"Human":"03 April 2013 08:10:09 GMT","HumanDate":"3. Apr"},"Title":"all good","Content":"Nothing went wrong - I\u0027m happy :-)","TrustScore":{"Score":100,"Stars":5,"Human":"Excellent","StarsImageUrls":{"large":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/l/5.png","medium":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/m/5.png","small":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/s/5.png"}},"CompanyReply":"","User":{"Name":"Thomas Wind Bøglund","City":"København","Locale":"da-DK","ReviewCount":1,"IsVerified":false,"HasImage":true,"ImageUrls":{"i24":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/1604652/24x24.png","i35":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/1604652/35x35.png","i64":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/1604652/64x64.png","i73":"//s3-eu-west-1.amazonaws.com/images.trustpilot.com/CloudImages/User/1604652/73x73.png"}},"Url":"http://www.trustpilot.co.uk/review/demoshop.com#4180257","IsVerified":true}],"TrustScore":{"Score":84,"Stars":4,"Human":"Good","StarsImageUrls":{"large":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/l/4.png","medium":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/m/4.png","small":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/s/4.png"}}}';

    const FEED_WITHOUT_REVIEWS = '{"Categories":[{"Name":"Accounting","Position":3,"Count":6,"ImageUrls":{"i100":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/category_badge/en_100_3.png","i120":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/category_badge/en_120_3.png","i140":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/category_badge/en_140_3.png","i180":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/category_badge/en_180_3.png","i220":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/category_badge/en_220_3.png","i280":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/category_badge/en_280_3.png"}},{"Name":"Bags and Luggage","Position":7,"Count":2,"ImageUrls":{"i100":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/category_badge/en_100_10.png","i120":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/category_badge/en_120_10.png","i140":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/category_badge/en_140_10.png","i180":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/category_badge/en_180_10.png","i220":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/category_badge/en_220_10.png","i280":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/category_badge/en_280_10.png"}}],"DomainName":"demoshop.com","FeedUpdateTime":{"UnixTime":1365089831,"Human":"04 April 2013 14:37:11 GMT","HumanDate":"4. Apr"},"ReviewCount":{"Total":105,"DistributionOverStars":[3,1,11,28,62]},"ReviewPageUrl":"http://www.trustpilot.co.uk/review/demoshop.com","Reviews":[],"TrustScore":{"Score":84,"Stars":4,"Human":"Good","StarsImageUrls":{"large":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/l/4.png","medium":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/m/4.png","small":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/s/4.png"}}}';

    const FEED_WITHOUT_CATEGORIES = '{"Categories":[],"DomainName":"demoshop.com","FeedUpdateTime":{"UnixTime":1365089831,"Human":"04 April 2013 14:37:11 GMT","HumanDate":"4. Apr"},"ReviewCount":{"Total":105,"DistributionOverStars":[3,1,11,28,62]},"ReviewPageUrl":"http://www.trustpilot.co.uk/review/demoshop.com","Reviews":[],"TrustScore":{"Score":84,"Stars":4,"Human":"Good","StarsImageUrls":{"large":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/l/4.png","medium":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/m/4.png","small":"//s3-eu-west-1.amazonaws.com/s.trustpilot.com/images/tpelements/stars/s/4.png"}}}';
}
